@@ -103,12 +103,23 @@ no_pin_deps = {
     'inverse':'pin-deps'
 }
 
+_conda_mode_param = {
+    'name': 'conda_mode',
+    'long': 'conda-mode',
+    'type': str,
+    'choices': [
+        ('conda', 'with classic conda exe'),
+        ('mamba', 'with mamba exe (must be installed)'),
+    ],
+    'default': 'conda',
+}
+
 # hack around envs inside envs etc
 CONDA_ROOT_EXE = os.environ.get('CONDA_EXE','conda') # TODO should at least warn if conda_exe not there; will be fixed as part of 0.7
 
 # TODO: not sure what conda-using developers do/prefer...
 # pip develop and don't install missing install deps or any build deps
-python_develop = "pip install --no-deps --no-build-isolation -e ."
+python_develop = "python -m pip install --no-deps --no-build-isolation -e ."
 # pip develop and pip install missing deps
 #  python_develop = "pip install -e ."
 # setuptools develop and don't install missing deps
@@ -118,11 +129,13 @@ python_develop = "pip install --no-deps --no-build-isolation -e ."
 
 from .util import _get_dependencies
 
-def _conda_build_deps(channel):
+def _conda_build_deps(channel, conda_mode):
     buildreqs = get_buildreqs()
     deps = " ".join('"%s"'%_join_the_club(dep) for dep in buildreqs)
     if len(buildreqs)>0:
-        return "conda install -y %s %s"%(" ".join(['-c %s'%c for c in channel]),deps)
+        cmd = "%s install -y %s %s" % (conda_mode, " ".join(['-c %s' % c for c in channel]), deps)
+        print('Install build dependencies with:', cmd)
+        return cmd
     else:
         return echo("Skipping conda install (no build dependencies)")
 
@@ -151,7 +164,7 @@ def _pin(deps):
     return pinneddeps
 
     
-def _conda_install_with_options(options,channel,env_name_again,no_pin_deps,all_extras):
+def _conda_install_with_options(options,channel,env_name_again,no_pin_deps,all_extras,conda_mode):
     # TODO: list v string form for _pin
     deps = _get_dependencies(['install_requires']+options,all_extras=all_extras)
     deps = [_join_the_club(d) for d in deps]
@@ -161,14 +174,16 @@ def _conda_install_with_options(options,channel,env_name_again,no_pin_deps,all_e
         deps = " ".join('"%s"'%dep for dep in deps)       
         # TODO and join the club? 
         e = '' if env_name_again=='' else '-n %s'%env_name_again
-        return "conda install -y " + e + " %s %s"%(" ".join(['-c %s'%c for c in channel]),deps)
+        cmd = "%s install -y " % (conda_mode) + e + " %s %s" % (" ".join(['-c %s' % c for c in channel]), deps)
+        print('Install runtime dependencies with:', cmd)
+        return cmd
     else:
         return echo("Skipping conda install (no dependencies)")
 
 
 # TODO: another parameter workaround
-def _conda_install_with_options_hacked(options,channel,no_pin_deps,all_extras):
-    return _conda_install_with_options(options,channel,'',no_pin_deps,all_extras)
+def _conda_install_with_options_hacked(options,channel,no_pin_deps,all_extras,conda_mode):
+    return _conda_install_with_options(options,channel,'',no_pin_deps,all_extras,conda_mode)
 
 ############################################################
 # TASKS...
@@ -870,7 +885,7 @@ def task_develop_install():
         CmdAction(_conda_build_deps),
         CmdAction(_conda_install_with_options_hacked),
         python_develop],
-            'params': [_options_param,_channel_param,no_pin_deps,_all_extras_param]}
+            'params': [_options_param,_channel_param,no_pin_deps,_all_extras_param,_conda_mode_param]}
 
 
 def task_env_dependency_graph():
